import {
  isVNode,
  provide,
  reactive,
  getCurrentInstance
} from "vue";
const flattenVNodes = (children) => {
  const result = [];
  const traverse = (children2) => {
    if (Array.isArray(children2)) {
      children2.forEach((child) => {
        var _a;
        if (isVNode(child)) {
          result.push(child);
          if ((_a = child.component) == null ? void 0 : _a.subTree) {
            traverse(child.component.subTree.children);
          }
          if (child.children) {
            traverse(child.children);
          }
        }
      });
    }
  };
  traverse(children);
  return result;
};
const sortChildren = (parent, publicChildren, internalChildren) => {
  const VNodes = flattenVNodes(parent.subTree.children);
  internalChildren.sort((a, b) => VNodes.indexOf(a.vnode) - VNodes.indexOf(b.vnode));
  const orderedPublicChildren = internalChildren.map((item) => item.proxy);
  publicChildren.sort((a, b) => {
    const indexA = orderedPublicChildren.indexOf(a);
    const indexB = orderedPublicChildren.indexOf(b);
    return indexA - indexB;
  });
};
const createProvider = (key) => {
  const publicChildren = reactive([]);
  const internalChildren = reactive([]);
  const parent = getCurrentInstance();
  const provider = (value) => {
    const link = (child) => {
      if (child.proxy) {
        internalChildren.push(child);
        publicChildren.push(child.proxy);
        sortChildren(parent, publicChildren, internalChildren);
      }
    };
    const unlink = (child) => {
      const idx = internalChildren.indexOf(child);
      publicChildren.splice(idx, 1);
      internalChildren.splice(idx, 1);
    };
    provide(key, Object.assign({
      link,
      unlink,
      children: publicChildren,
      internalChildren
    }, value));
  };
  return {
    children: publicChildren,
    provider
  };
};
export {
  createProvider,
  flattenVNodes,
  sortChildren
};
